@@ -1,5 +1,6 @@
 from .common import DatasetRegistry, Usages, DatasetTypes, CocoManifestAdaptor, IrisManifestAdaptor, DatasetManifest, DatasetInfo, ManifestDataset, BaseDatasetInfo, MultiTaskDatasetInfo
 from .resources import DatasetHub
+from .commands import Base64Utils
 
 __all__ = ['DatasetRegistry', 'Usages', 'DatasetTypes', 'CocoManifestAdaptor', 'IrisManifestAdaptor', 'DatasetManifest', 'DatasetInfo', 'ManifestDataset', 'BaseDatasetInfo', 'MultiTaskDatasetInfo',
-           'DatasetHub']
+           'DatasetHub', 'Base64Utils']
